@@ -4,6 +4,4 @@ default_app_config = "django_fastadmin.apps.DjangoFastadminConfig"
 app_requires = [
     "django_static_jquery3",
     "django_static_ace_builds",
-    "django_apiview",
-    "django_db_lock",
 ]
