@@ -55,7 +55,7 @@ class InlineBooleanFieldsAllowOnlyOneCheckedMixin(InlineModelAdmin):
     class Media:
         js = jquery_plugins([
             "jquery/plugins/jquery.utils.js",
-            "fastadmin/admins/inline-boolean-fields-allow-only-one-checked-mixin/inline-boolean-fields-allow-only-one-checked-mixin.js",
+            "fastadmin/admins/inline-boolean-fields-allow-only-one-checked-mixin/ibfaoocm.js",
         ])
 
 class InlineUniqueChoiceFieldsMixin(InlineModelAdmin):
@@ -449,29 +449,6 @@ class ToggleFieldStateAdmin(AddAdminViewHelper, admin.ModelAdmin):
             }
         return toggle_field_state_button
 
-class SimplePublishModelAdmin(ToggleFieldStateAdmin, admin.ModelAdmin):
-
-    published_field_name = "published"
-
-    toggle_publish_state_button_title_turn_on = _("Publish")
-    toggle_publish_state_button_title_turn_off = _("Unpublish")
-    toggle_publish_state_button_icon_state_on = "fa fa-eye-slash"
-    toggle_publish_state_button_icon_state_off = "fa fa-eye"
-    toggle_publish_state_button_help_text = _("Toggle item publish state.")
-
-    def get_toggle_field_state_configs(self):
-        configs = super().get_toggle_field_state_configs()
-        configs[self.published_field_name] = {
-            "toggle_button_title_turn_on": self.toggle_publish_state_button_title_turn_on,
-            "toggle_button_title_turn_off": self.toggle_publish_state_button_title_turn_off,
-            "toggle_button_icon_state_on": self.toggle_publish_state_button_icon_state_on,
-            "toggle_button_icon_state_off": self.toggle_publish_state_button_icon_state_off,
-            "toggle_button_help_text": self.toggle_publish_state_button_help_text,
-        }
-        return configs
-
-    toggle_publish_state_button = ToggleFieldStateAdmin.make_toggle_field_state_button("published_field_name")
-
 class SetTopModelAdmin(ToggleFieldStateAdmin, admin.ModelAdmin):
 
     is_top_field_name = "is_top"
